#ifndef PYTHONIC_NUMPY_RESIZE_HPP
#define PYTHONIC_NUMPY_RESIZE_HPP

#include "pythonic/include/numpy/resize.hpp"

#include "pythonic/utils/functor.hpp"
#include "pythonic/numpy/ndarray/reshape.hpp"

#endif
