#ifndef PYTHONIC_INCLUDE_NUMPY_PI_HPP
#define PYTHONIC_INCLUDE_NUMPY_PI_HPP

#include "pythonic/include/math/pi.hpp"

PYTHONIC_NS_BEGIN

namespace numpy
{
  double constexpr pi = math::pi;
}
PYTHONIC_NS_END

#endif
