

set -ex



export CBS="-isysroot $(xcrun --show-sdk-path)"
export CFLAGS="${CFLAGS} ${CBS}"
export CXXFLAGS="${CXXFLAGS} ${CBS}"
export LDFLAGS="${LDFLAGS} ${CBS}"
pythran -v dprod.py
python -c "import dprod"
pythran -v simple_numexpr.py -DUSE_XSIMD
python -c "import simple_numexpr"
exit 0
