#ifndef PYTHONIC_INCLUDE_STRING_HEXDIGITS_HPP
#define PYTHONIC_INCLUDE_STRING_HEXDIGITS_HPP

#include "pythonic/types/str.hpp"

PYTHONIC_NS_BEGIN

namespace string
{
  types::str constexpr hexdigits("0123456789abcdefABCDEF");
}
PYTHONIC_NS_END

#endif
