#ifndef PYTHONIC_OPERATOR_IAND_HPP
#define PYTHONIC_OPERATOR_IAND_HPP

#include "pythonic/include/operator_/iand.hpp"

#define OPERATOR_NAME iand
#define OPERATOR_SYMBOL &
#define OPERATOR_ISYMBOL &=

#include "pythonic/operator_/icommon.hpp"

#endif
