#ifndef PYTHONIC_INCLUDE_OPERATOR_IOR_HPP
#define PYTHONIC_INCLUDE_OPERATOR_IOR_HPP

#define OPERATOR_NAME ior
#define OPERATOR_SYMBOL |
#define OPERATOR_ISYMBOL |=
#include "pythonic/include/operator_/icommon.hpp"

#endif
