#ifndef PYTHONIC_INCLUDE_OPERATOR_AND__HPP
#define PYTHONIC_INCLUDE_OPERATOR_AND__HPP

#include "pythonic/include/operator_/and_.hpp"

PYTHONIC_NS_BEGIN

namespace operator_
{

  USING_FUNCTOR(__and__, and_);
}
PYTHONIC_NS_END

#endif
